const path = require('path');
const slueStream = require('slue-stream');
const babel = require('babel-core');
const UglifyJS = require("uglify-js");

module.exports = function(opts) {
    return slueStream.transformObj(function(file, env, cb) {
        let extname = path.extname(file.path);
        if (extname === '.js') {
            let contents = file.contents.toString();

            try {
                let result = babel.transform(contents, {
                    presets: [
                        require('babel-preset-env'),
                        require('babel-preset-react'),
                        require('babel-preset-stage-3')
                    ]
                });
                contents = result.code;
            } catch (e) {
                e.filePath = file.path;
                console.log(e);
            }

            for (let env in opts) {
                let regular = new RegExp(`process\\\.env\\\.${env}[^z-zA-Z_0-9]`, 'g');
                contents = contents.replace(regular, function(item) {
                    let _regular = new RegExp(`process\\\.env\\\.${env}`, 'g');
                    item = item.replace(_regular, `\'${opts[env]}\'`);
                    return item;
                });
            }

            let res = UglifyJS.minify(contents, {
                output: {
                    beautify: true
                }
            });
            if (res.error) {
                res.error.filePath = file.path;
                console.log(res.error);
            } else {
                file.contents = Buffer.from(res.code);
            }

            cb(null, file);
        } else {
            cb(null, file);
        }
    });
}